@@ -1,19 +1,19 @@
-/*  libhdate
- *  Copyright  2004-2005  Yaacov Zamir <kzamir@walla.co.il>
+/*  libhdate - Hebrew calendar library
+ *
+ *  Copyright (C) 1984-2003 Amos Shapir, 2004-2007  Yaacov Zamir <kzamir@walla.co.il>
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -25,6 +25,7 @@
 #include <time.h>
 #include <stdio.h>
 #include <math.h>
+#include <errno.h>
 
 #include "hdate.h"
 #include "support.h"
@@ -56,15 +57,23 @@ hdate_get_day_of_year (int day, int month, int year)
 
 /**
  @brief utc sun times for altitude at a gregorian date
-  
- @parm day this day of month
- @parm month this month
- @parm year this year
- @parm longitude longitude to use in calculations
- @parm latitude latitude to use in calculations
- @parm deg degrees of sun's altitude (0 -  Zenith .. 90 - Horizon)
- @parm sunrise return the utc sunrise in minutes
- @parm sunset return the utc sunset in minutes
+
+ Returns the sunset and sunrise times in minutes from 00:00 (utc time)
+ if sun altitude in sunrise is deg degries.
+ This function only works for altitudes sun realy is.
+ If the sun never get to this altitude, the returned sunset and sunrise values 
+ will be negative. This can happen in low altitude when latitude is 
+ nearing the pols in winter times, the sun never goes very high in 
+ the sky there.
+
+ @param day this day of month
+ @param month this month
+ @param year this year
+ @param longitude longitude to use in calculations
+ @param latitude latitude to use in calculations
+ @param deg degrees of sun's altitude (0 -  Zenith .. 90 - Horizon)
+ @param sunrise return the utc sunrise in minutes
+ @param sunset return the utc sunset in minutes
 */
 void
 hdate_get_utc_sun_time_deg (int day, int month, int year, double latitude, double longitude, double deg, int *sunrise, int *sunset)
@@ -97,8 +106,18 @@ hdate_get_utc_sun_time_deg (int day, int month, int year, double latitude, doubl
 	latitude = M_PI * latitude / 180.0;
 	
 	/* the sun real time diff from noon at sunset/rise in radians */
+  errno = 0;
 	ha = acos (cos (sunrise_angle) / (cos (latitude) * cos (decl)) - tan (latitude) * tan (decl));
 	
+  /* check for too high altitudes and return negative values */
+  if (errno == EDOM)
+  {
+    *sunrise = -720;
+	  *sunset = -720;
+    
+    return;
+  }
+  
 	/* we use minutes, ratio is 1440min/2pi */
 	ha = 720.0 * ha / M_PI;
 	
