@@ -1,26 +1,27 @@
-/*  libhdate
- *  Copyright  2004-2005  Yaacov Zamir <kzamir@walla.co.il>
+/*  libhdate - Hebrew calendar library
+ *
+ *  Copyright (C) 1984-2003 Amos Shapir, 2004-2007  Yaacov Zamir <kzamir@walla.co.il>
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*
- * See Amos Shapir hdate_README file attached for 
- * Copyright notice for functions based on Amos's code
- */
- 
+/** @file hdatepp.h
+    @brief libhdate C++ language header.
+    
+    libhdate - Hebrew calendar library, the C++ language header file.
+*/
+
 #ifndef __HDATE_PP_H__
 #define __HDATE_PP_H__
 
@@ -59,7 +60,7 @@ namespace hdate
 			h = new_hdate();
 			
 			/* default is in israel */
-			diaspora = HDATA_ISRAEL_FLAG;
+			diaspora = HDATE_ISRAEL_FLAG;
 			
 			/* default localeconv is Tel-Aviv winter time */
 			latitude = 32.0;
@@ -581,7 +582,7 @@ namespace hdate
 		void
 		set_diaspora ()
 		{
-			diaspora = HDATA_DIASPORA_FLAG;
+			diaspora = HDATE_DIASPORA_FLAG;
 		}
 		
 		/**
@@ -590,7 +591,7 @@ namespace hdate
 		void
 		set_israel ()
 		{
-			diaspora = HDATA_ISRAEL_FLAG;
+			diaspora = HDATE_ISRAEL_FLAG;
 		}
 		
 	private:
